@@ -13,9 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Epiphany; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -80,7 +78,6 @@ main (int argc, char *argv[])
   gtk_test_init (&argc, &argv);
 
   ephy_debug_init ();
-  ephy_embed_prefs_init ();
 
   if (!ephy_file_helpers_init (NULL,
                                EPHY_FILE_HELPERS_PRIVATE_PROFILE | EPHY_FILE_HELPERS_ENSURE_EXISTS,
@@ -100,8 +97,8 @@ main (int argc, char *argv[])
 
   ret = g_test_run ();
 
-  ephy_file_helpers_shutdown ();
   g_object_unref (ephy_shell_get_default ());
+  ephy_file_helpers_shutdown ();
 
   return ret;
 }
